gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r18302 - gnunet/src/mesh


From: gnunet
Subject: [GNUnet-SVN] r18302 - gnunet/src/mesh
Date: Thu, 24 Nov 2011 15:44:07 +0100

Author: bartpolot
Date: 2011-11-24 15:44:07 +0100 (Thu, 24 Nov 2011)
New Revision: 18302

Modified:
   gnunet/src/mesh/gnunet-service-mesh.c
   gnunet/src/mesh/mesh_api.c
   gnunet/src/mesh/mesh_tunnel_tree.c
   gnunet/src/mesh/mesh_tunnel_tree.h
Log:
- Updated doxygen

Modified: gnunet/src/mesh/gnunet-service-mesh.c
===================================================================
--- gnunet/src/mesh/gnunet-service-mesh.c       2011-11-24 14:11:55 UTC (rev 
18301)
+++ gnunet/src/mesh/gnunet-service-mesh.c       2011-11-24 14:44:07 UTC (rev 
18302)
@@ -769,6 +769,7 @@
  * Send the message to all clients that have subscribed to its type
  *
  * @param msg Pointer to the message itself
+ * @param payload Pointer to the payload of the message.
  * @return number of clients this message was sent to
  */
 static unsigned int
@@ -2178,7 +2179,7 @@
  * The tunnel itself is also destoyed if results in a remote empty tunnel.
  *
  * @param t Tunnel from which to remove the path.
- * @param p Peer which should be removed.
+ * @param peer Short id of the peer which should be removed.
  */
 static void
 tunnel_delete_peer (struct MeshTunnel *t, GNUNET_PEER_Id peer)
@@ -3260,6 +3261,10 @@
  * @param cls closure
  * @param exp when will this value expire
  * @param key key of the result
+ * @param get_path path of the get request
+ * @param get_path_length lenght of get_path
+ * @param put_path path of the put request
+ * @param put_path_length length of the put_path
  * @param type type of the result
  * @param size number of bytes in data
  * @param data pointer to the result data
@@ -3305,6 +3310,10 @@
  * @param cls closure
  * @param exp when will this value expire
  * @param key key of the result
+ * @param get_path path of the get request
+ * @param get_path_length lenght of get_path
+ * @param put_path path of the put request
+ * @param put_path_length length of the put_path
  * @param type type of the result
  * @param size number of bytes in data
  * @param data pointer to the result data

Modified: gnunet/src/mesh/mesh_api.c
===================================================================
--- gnunet/src/mesh/mesh_api.c  2011-11-24 14:11:55 UTC (rev 18301)
+++ gnunet/src/mesh/mesh_api.c  2011-11-24 14:44:07 UTC (rev 18302)
@@ -368,8 +368,10 @@
  * - Cancels all outgoing traffic for that tunnel, calling respective notifys
  * - Calls cleaner if tunnel was inbound
  * - Frees all memory used
- * @param tid ID of the wanted tunnel
- * @return handle to the required tunnel or NULL if not found
+ *
+ * @param t Pointer to the tunnel.
+ *
+ * @return Handle to the required tunnel or NULL if not found.
  */
 static void
 destroy_tunnel (struct GNUNET_MESH_Tunnel *t)
@@ -1304,7 +1306,7 @@
 /**
  * Destroy an existing tunnel.
  *
- * @param tun tunnel handle
+ * @param tunnel tunnel handle
  */
 void
 GNUNET_MESH_tunnel_destroy (struct GNUNET_MESH_Tunnel *tunnel)

Modified: gnunet/src/mesh/mesh_tunnel_tree.c
===================================================================
--- gnunet/src/mesh/mesh_tunnel_tree.c  2011-11-24 14:11:55 UTC (rev 18301)
+++ gnunet/src/mesh/mesh_tunnel_tree.c  2011-11-24 14:44:07 UTC (rev 18302)
@@ -110,7 +110,7 @@
 /**
  * Create a new path
  *
- * @param lenght How many hops will the path have.
+ * @param length How many hops will the path have.
  *
  * @return A newly allocated path with a peer array of the specified length.
  */
@@ -132,7 +132,7 @@
 /**
  * Invert the path
  *
- * @param p the path to invert
+ * @param path the path to invert
  */
 void
 path_invert (struct MeshPeerPath *path)
@@ -152,7 +152,7 @@
 /**
  * Duplicate a path, incrementing short peer's rc.
  *
- * @param p The path to duplicate.
+ * @param path The path to duplicate.
  */
 struct MeshPeerPath *
 path_duplicate (struct MeshPeerPath *path)
@@ -172,7 +172,7 @@
  * Recusively update the info about what is the first hop to reach the node
  *
  * @param tree Tree this nodes belongs to.
- * @param parent_id Short ID from node form which to start updating.
+ * @param parent The node form which to start updating.
  * @param hop If known, ID of the first hop.
  *            If not known, NULL to find out and pass on children.
  */
@@ -183,12 +183,12 @@
 
 
 /**
- * Get the length of a path
+ * Get the length of a path.
  *
- * @param path The path to measure, with the local peer at any point of it
+ * @param path The path to measure, with the local peer at any point of it.
  *
- * @return Number of hops to reach destination
- *         UINT_MAX in case the peer is not in the path
+ * @return Number of hops to reach destination.
+ *         UINT_MAX in case the peer is not in the path.
  */
 unsigned int
 path_get_length (struct MeshPeerPath *path)
@@ -249,7 +249,7 @@
  * Recursively find the given peer.
  *
  * @param parent Node where to start looking.
- * @param peer Peer to find.
+ * @param peer_id Short ID of the peer to find.
  *
  * @return Pointer to the node of the peer. NULL if not found.
  */
@@ -371,7 +371,7 @@
 /**
  * Destroys and frees the node and all children
  *
- * @param n Parent node to be destroyed
+ * @param parent Parent node to be destroyed
  */
 static void
 tree_node_destroy (struct MeshTunnelTreeNode *parent)
@@ -404,12 +404,11 @@
 
 
 /**
- * Create a new tunnel tree associated to a tunnel
+ * Create a new tree.
  *
- * @param t Tunnel this tree will represent
- * @param peer A short peer id of the root of the tree
+ * @param peer A short peer id of the root of the tree.
  *
- * @return A newly allocated and initialized tunnel tree
+ * @return A newly allocated and initialized tunnel tree.
  */
 struct MeshTunnelTree *
 tree_new (GNUNET_PEER_Id peer)
@@ -434,7 +433,8 @@
  * Set the status of a node.
  *
  * @param tree Tree.
- * @param peer A short peer id of local peer.
+ * @param peer A short peer id of the node.
+ * @param status New status to set.
  */
 void
 tree_set_status (struct MeshTunnelTree *tree, GNUNET_PEER_Id peer,
@@ -452,9 +452,10 @@
 /**
  * Get the status of a node.
  *
- * @param tree Tree whose local id we want to now.
+ * @param tree Tree whose node's status we want to now.
+ * @param peer A short peer id of the node.
  *
- * @return Short peer id of local peer.
+ * @return Status of the peer.
  */
 enum MeshPeerState
 tree_get_status (struct MeshTunnelTree *tree, GNUNET_PEER_Id peer)
@@ -529,7 +530,7 @@
  * Find the given peer in the tree.
  *
  * @param tree Tree where to look for the peer.
- * @param peer Peer to find.
+ * @param peer_id Short ID of the peer to find.
  *
  * @return Pointer to the node of the peer. NULL if not found.
  */
@@ -546,6 +547,7 @@
  * @param tree Tree this node belongs to
  * @param parent Node to be clean, potentially with children
  * @param cb Callback to use to notify about disconnected peers.
+ * @param cbcls Closure for cb.
  */
 static void
 tree_mark_peers_disconnected (struct MeshTunnelTree *tree,
@@ -623,7 +625,7 @@
  * a new path to it or destroy it explicitly, taking care of it's child nodes.
  *
  * @param t Tunnel tree where to delete the path from.
- * @param peer Destination peer whose path we want to remove.
+ * @param peer_id Short ID of the destination peer whose path we want to 
remove.
  * @param cb Callback to use to notify about disconnected peers.
  * @param cbcls Closure for cb.
  *
@@ -694,8 +696,8 @@
  * Return a newly allocated individual path to reach a peer from the local 
peer,
  * according to the path tree of some tunnel.
  *
- * @param t Tunnel from which to read the path tree
- * @param peer_info Destination peer to whom we want a path
+ * @param t Tunnel from which to read the path tree.
+ * @param peer Short ID of the destination peer to whom we want a path.
  *
  * @return A newly allocated individual path to reach the destination peer.
  *         Path must be destroyed afterwards.

Modified: gnunet/src/mesh/mesh_tunnel_tree.h
===================================================================
--- gnunet/src/mesh/mesh_tunnel_tree.h  2011-11-24 14:11:55 UTC (rev 18301)
+++ gnunet/src/mesh/mesh_tunnel_tree.h  2011-11-24 14:44:07 UTC (rev 18302)
@@ -19,7 +19,7 @@
 */
 
 /**
- * @file mesh/mesh_tree_tree.h
+ * @file mesh/mesh_tunnel_tree.h
  * @brief Tunnel tree handling functions
  * @author Bartlomiej Polot
  */
@@ -72,9 +72,9 @@
 
/******************************************************************************/
 
 /**
- * Create a new path
+ * Create a new path.
  *
- * @param lenght How many hops will the path have.
+ * @param length How many hops will the path have.
  *
  * @return A newly allocated path with a peer array of the specified length.
  */
@@ -83,33 +83,33 @@
 
 
 /**
- * Invert the path
+ * Invert the path.
  *
- * @param p the path to invert
+ * @param path The path to invert.
  */
 void
-path_invert (struct MeshPeerPath *p);
+path_invert (struct MeshPeerPath *path);
 
 
 /**
  * Duplicate a path, incrementing short peer's rc.
  *
- * @param p The path to duplicate.
+ * @param path The path to duplicate.
  */
 struct MeshPeerPath *
 path_duplicate (struct MeshPeerPath *path);
 
 
 /**
- * Get the length of a path
+ * Get the length of a path.
  *
- * @param p The path to measure, with the local peer at any point of it
+ * @param path The path to measure, with the local peer at any point of it.
  *
- * @return Number of hops to reach destination
- *         UINT_MAX in case the peer is not in the path
+ * @return Number of hops to reach destination.
+ *         UINT_MAX in case the peer is not in the path.
  */
 unsigned int
-path_get_length (struct MeshPeerPath *p);
+path_get_length (struct MeshPeerPath *path);
 
 
 /**
@@ -149,7 +149,8 @@
  * Set the status of a node.
  *
  * @param tree Tree.
- * @param peer A short peer id of local peer.
+ * @param peer A short peer id of the node.
+ * @param status New status to set.
  */
 void
 tree_set_status (struct MeshTunnelTree *tree, GNUNET_PEER_Id peer,
@@ -160,6 +161,7 @@
  * Get the status of a node.
  *
  * @param tree Tree whose local id we want to now.
+ * @param peer A short peer id of the node.
  *
  * @return Short peer id of local peer.
  */
@@ -233,7 +235,7 @@
  * a new path to it or destroy it explicitly, taking care of it's child nodes.
  *
  * @param t Tunnel tree where to delete the path from.
  * @param peer Destination peer whose path we want to remove.
remove.
  * @param cb Callback to use to notify about which peers are going to be
  *           disconnected.
  * @param cbcls Closure for cb.
@@ -242,7 +244,7 @@
  *         NULL when not found
  */
 struct MeshTunnelTreeNode *
-tree_del_path (struct MeshTunnelTree *t, GNUNET_PEER_Id peer,
+tree_del_path (struct MeshTunnelTree *t, GNUNET_PEER_Id peer_id,
                MeshTreeCallback cb, void *cbcls);
 
 
@@ -233,7 +235,7 @@
  *
  * @param t Tunnel tree where to delete the path from.
- * @param peer Destination peer whose path we want to remove.
+ * @param peer_id Short ID of the destination peer whose path we want to 
remove.
  * @param cb Callback to use to notify about which peers are going to be




reply via email to

[Prev in Thread] Current Thread [Next in Thread]